@@ -257,14 +257,13 @@ sub Mojolicious::dispatch {
 
   # Start timer (ignore static files)
   my $stash = $c->stash;
-  unless ($stash->{'mojo.static'} || $stash->{'mojo.started'}) {
+  $self->log->debug(sub {
     my $req    = $c->req;
-    my $method = $req->method;
-    my $path   = $req->url->path->to_route;#to_abs_string;
-    my $id     = $req->request_id;
-    $self->log->debug(qq{$method "$path" ($id)});
+    my $url = $req->url->to_abs;
     $c->helpers->timing->begin('mojo.timer');
-  }
+    return sprintf qq{%s "%s://%s%s%s" (%s)},
+      $req->method, $url->scheme, $url->host, $url->port ? ":".$url->port : '', $url->path->to_route, $req->request_id;
+  }) unless $stash->{'mojo.static'};
 
   # Routes
   $plugins->emit_hook(before_routes => $c);
@@ -273,7 +272,7 @@ sub Mojolicious::dispatch {
 }
 
 
-our $VERSION = '0.08031';# as to Mojolicious 8.02
+our $VERSION = '0.08071';# as to Mojolicious/100+0.000<minor>
 
 =pod
 
@@ -287,7 +286,7 @@ our $VERSION = '0.08031';# as to Mojolicious 8.02
 
 =head1 VERSION
 
-0.08031
+0.08071
 
 =head1 NAME
 
